---
layout: single
title: "Field Methods to Study Wildfire"
excerpt: "Scientists often use field survey methods to study the impacts of wildfire through measurements of biomass and soil. Learn more about how survey methods can be used to study wildfire impacts."
authors: ['Leah Wasser']
dateCreated: 2018-10-04
modified: 2020-09-11
category: [courses]
class-lesson: ['wildfire-overview-tb']
permalink: /courses/use-data-open-source-python/data-stories/cold-springs-wildfire/wildfire-field-methods/
nav-title: 'Field Studies of Wildfire Impacts'
week: 9
course: 'intermediate-earth-data-science-textbook'
module-type: 'class'
sidebar:
  nav:
author_profile: false
comments: true
order: 2
topics:
  earth-science: ['fire']
redirect_from:
  - "/courses/earth-analytics-python/multispectral-remote-sensing-in-python/wildfire-field-methods/"
---

{% include toc title="On This Page" icon="file-text" %}

<div class='notice--success' markdown="1">

## <i class="fa fa-graduation-cap" aria-hidden="true"></i> Learning Objectives

* Explain why scientists study wildfire.
* List the types of field measurements that scientists gather to study wildfire.

</div>


## How Scientists Study Fire

While fires naturally occur in most ecological systems, they also have large impacts on both humans and wildlife. Thus, there is significant effort to study fire, in order to, among other things:

* Predict future fire behaviour (and potentially save lives and minimize evacuation efforts).
* Understand how humans impact fire intensity and frequency over time.
* Understand how fire is impacted by climate.

The impacts of wildfires like the Cold Springs Fire can be measured in a number of ways including:

* **Field surveys:** Humans taking manual measurements of vegetation loss and soil characteristics at a fire site.
* **Remote sensing:** Data from satellites, unmanned aerial vehicles (UAVs), and planes can be used to to calculate quantitative metrics. This can include burn severity, changes before versus after the burn in vegetation, and differences between the burn site and areas around it that did not burn. This data can also be used to monitor ecosystem recovery. 

In this lesson, you will learn more about how scientists use field surveys to study the impacts of wildfire.  


## Field Surveys to Understand Fire

When studying fire in the field, scientists will often collect vegetation and soil samples either before and after fire or in burned and unburned areas. From vegetation surveys and sample collection, they can calculate **standing biomass** or measure soil properties. 

<i class="fa fa-star"></i> Definition: **Standing biomass** is the total mass of living matter in a particular area, including trees, shrubs, and grasses.
{: .notice--success}

Standing biomass can be broken down by type or species, such as shrub biomass or woody plant biomass. The biomass of grasses and woody plants correlates to increased wildfire risk as these are the species that most commonly fuel fires. 

To calculate the standing biomass of a tree, you measure the tree’s diameter (and sometimes height) and then use an equation (based on previous studies on these trees) to calculate biomass. For grasses and shrubs, you measure their percent cover and then harvest samples and bring them to a laboratory where you dry and weigh them for biomass analysis. 

<figure>
  <a href="{{ site.url }}/images/earth-analytics/science/cold-springs-fire/students-fieldwork-cold-springs-fire-1.jpg">
    <img src="{{ site.url }}/images/earth-analytics/science/cold-springs-fire/students-fieldwork-cold-springs-fire-1.jpg" alt="CU Boulder students perform fieldwork at the site of the Cold Springs Fire.">
  </a>
  <figcaption>University of Colorado Boulder Earth Lab postdocs and graduate students measure the diameter of a tree to calculate standing biomass at the Cold Springs Fire site on November 2nd, 2016. Source: Nate Mietkiewicz.
  </figcaption>
</figure>

<figure>
  <a href="{{ site.url }}/images/earth-analytics/science/cold-springs-fire/students-fieldwork-cold-springs-fire-3.jpg">
    <img src="{{ site.url }}/images/earth-analytics/science/cold-springs-fire/students-fieldwork-cold-springs-fire-3.jpg" alt="CU Boulder students perform fieldwork at the site of the Cold Springs Fire.">
  </a>
  <figcaption>University of Colorado Boulder Earth Lab students perform fieldwork at the Cold Springs Fire site on November 21st, 2016 . Source: Nate Mietkiewicz.
  </figcaption>
</figure>


Soil measurements include measuring the content of organic material or nutrients like nitrogen, phosphorus, and sulfur. These measurements can help assess fire severity. For example, a more intense fire can burn the entire organic layer on the surface of the soil. Scientists might also measure physical properties such as pore space and water repellency. Water repellency caused by a fire may increase erosion and remove soil from the fire site. 

In addition to biomass and soil calculations,  field surveys are often performed to categorize the vegetation health. Scientists measure things like the percentage of leaves alive on a tree or they will count the number of pinecones in a given area to see if seeds survived. 


<figure>
  <a href="{{ site.url }}/images/earth-analytics/science/cold-springs-fire/students-fieldwork-cold-springs-fire-2.jpg">
    <img src="{{ site.url }}/images/earth-analytics/science/cold-springs-fire/students-fieldwork-cold-springs-fire-2.jpg" alt="A CU Boulder student performs fieldwork at the site of the Cold Springs Fire.">
  </a>
  <figcaption>A University of Colorado Boulder Earth Lab postdoc performs fieldwork at the Cold Springs Fire site on November 2nd, 2016. Source: Nate Mietkiewicz.
  </figcaption>
</figure>

